import Foundation 

struct FailableCodable<T: Codable>: Codable {
    let value: T?
    let error: Error?
    
    init(from decoder: Decoder) throws {
        do {
            self.value = try T(from: decoder)
            self.error = nil
        } catch {
            self.value = nil
            self.error = error
        }
    }
    
    func encode(to encoder: Encoder) throws {
        try self.value?.encode(to: encoder)
    }
}